@@ -91,7 +91,7 @@ class ZenBufferedLogHandler(logging.Handler):
         self.buffer = deque(maxlen=length)
 
     def emit(self, record):
-        self.buffer.append(self.format(record))
+        self.buffer.appendleft(self.format(record))
 
     def flush(self):
         try:
